==> passwordsafe_0.98.1+dfsg.orig.tar.gz: pwsafe-0.98.1BETA/src/core/core.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_FLDNMGROUPTITLE            3003
#define IDSC_FLDNMUSERNAME              3004
#define IDSC_FLDNMPASSWORD              3005
#define IDSC_FLDNMURL                   3006
#define IDSC_FLDNMAUTOTYPE              3007
#define IDSC_FLDNMCTIME                 3008
#define IDSC_FLDNMPMTIME                3009
#define IDSC_FLDNMATIME                 3010
#define IDSC_FLDNMXTIME                 3011
#define IDSC_FLDNMRMTIME                3012
#define IDSC_FLDNMPWHISTORY             3013
#define IDSC_FLDNMNOTES                 3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_UNKNOWN_ERROR              3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_MSXMLPARSEERROR            3043
#define IDSC_MSXMLBADCREATESCHEMA       3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOMSXMLREADER              3047
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_XMLSAVEFAILURE             3051
#define IDSC_SAXERRORPWH                3052
#define IDSC_MSXMLSAXGENERROR           3053
#define IDSC_XERCESSAXGENERROR          3054
#define IDSC_FLDNMGROUP                 3055
#define IDSC_FLDNMTITLE                 3056
#define IDSC_FLDNMPWPOLICY              3057
#define IDSC_FLDNMXTIMEINT              3058
#define IDSC_XERCESPARSEERROR           3059
#define IDCS_XERCESEXCEPTION            3060
#define IDCS_XERCESOUTOFMEMORY          3061
#define IDSC_FLDNMRUNCOMMAND            3063
#define IDSC_FLDNMDCA                   3064
#define IDSC_FLDNMEMAIL                 3065
#define IDSC_FLDNMPROTECTED             3066
#define IDSC_FLDNMUUID                  3067
#define IDSC_FLDNMSYMBOLS               3068
#define IDSC_INVALIDFIELDLENGTH         3069
#define IDSC_INVALIDPWLENGTHX           3070
#define IDSC_FLDNMSHIFTDCA              3071
#define IDSC_FLDNMPWPOLICYNAME          3072
#define IDSC_FLDNMKBSHORTCUT            3073

#define IDSC_CONFIG_NONE                3230
#define IDSC_CONFIG_REGISTRY            3231
#define IDSC_CONFIG_FILE_RO             3232
#define IDSC_CONFIG_FILE_RW             3233

#define IDSC_IMPORTNUMBER               3240
#define IDSC_IMPORTFAILURE              3241
#define IDSC_IMPORTHDR                  3242
#define IDSC_IMPORTMISSINGCOLS          3243
#define IDSC_IMPORTNOCOLS               3244
#define IDSC_READ_ERROR                 3245
#define IDSC_ENCODING_PROBLEM           3246

#define IDSC_FILEREADONLY               3247
#define IDSC_FILEEXISTS                 3248
#define IDSC_INVALIDFLAG                3249
#define IDSC_NOMOREHANDLES              3250
#define IDSC_FILEPATHNOTFOUND           3102
#define IDSC_BADPASSWORD                3251

#define IDSC_REPORTFILENAME             3252
#define IDSC_REPORT_TITLE1              3253
#define IDSC_REPORT_TITLE2              3254
#define IDSC_START_REPORT               3255
#define IDSC_END_REPORT1                3256
#define IDSC_END_REPORT2                3257

#define IDSC_IMPORTNOHEADER             3258
#define IDSC_IMPORTLINESKIPPED          3259
#define IDSC_IMPORTKNOWNHDRS            3260
#define IDSC_IMPORTEMPTYLINESKIPPED     3261
#define IDSC_PWHERRORLINE               3262
#define IDSC_PWHISTORYSKIPPED           3263
#define IDSC_IMPORTCONFLICTS1           3264
#define IDSC_IMPORTCONFLICTS2           3265
#define IDSC_IMPORTINVALIDFIELD         3266
#define IDSC_IMPORTNOPASSWORD           3268
#define IDSC_IMPORTNOTITLE              3269
#define IDSC_VALIDATE_BADUUID           3270
#define IDSC_VALIDATE_PWH               3271
#define IDSC_IMPORTWARNINGHDR           3272
#define IDSC_IMPORTWARNING1             3273
#define IDSC_IMPORTWARNING1A            3274
#define IDSC_IMPORTWARNING2             3275
#define IDSC_IMPORTWARNING2A            3276
#define IDSC_IMPORTWARNING3             3277
#define IDSC_ALIAS                      3278
#define IDSC_SHORTCUT                   3279
#define IDSC_FNORMAL                    3281
#define IDSC_FALIAS                     3282
#define IDSC_FSHORTCUT                  3283
#define IDSC_FALIASBASE                 3284
#define IDSC_FSHORTCUTBASE              3285
#define IDSC_EQUALS                     3286
#define IDSC_DOESNOTEQUAL               3287
#define IDSC_BEGINSWITH                 3288
#define IDSC_DOESNOTBEGINSWITH          3289
#define IDSC_ENDSWITH                   3290
#define IDSC_DOESNOTENDWITH             3291
#define IDSC_CONTAINS                   3292
#define IDSC_DOESNOTCONTAIN             3293
#define IDSC_IS                         3294
#define IDSC_ISNOT                      3295
#define IDSC_ISPRESENT                  3296
#define IDSC_ISNOTPRESENT               3297
#define IDSC_ISACTIVE                   3298
#define IDSC_ISINACTIVE                 3299
#define IDSC_SET                        3300
#define IDSC_NOTSET                     3301
#define IDSC_INVALID                    3302
#define IDSC_BETWEEN                    3303
#define IDSC_LESSTHAN                   3304
#define IDSC_LESSTHANEQUAL              3305
#define IDSC_GREATERTHAN                3306
#define IDSC_GREATERTHANEQUAL           3307
#define IDSC_BEFORE                     3308
#define IDSC_AFTER                      3309
#define IDSC_CASE_INSENSITIVE           3310
#define IDSC_CASE_SENSITIVE             3311
#define IDSC_EXPIRED                    3312
#define IDSC_WILLEXPIRE                 3313
#define IDSC_EXPIRE_IN_DAYS             3314
#define IDSC_SEEPWHISTORYFILTERS        3315
#define IDSC_SEEPWPOLICYFILTERS         3316
#define IDSC_CANTPROCESSDBFILTERS       3317
#define IDSC_INVALID_SCHEMA             3318
#define IDSC_INVALID_SCHEMA_VER         3319
#define IDSC_MISSING_SCHEMA_VER         3320
#define IDSC_MISSING_XML_VER            3321
#define IDSC_INVALID_XML_VER1           3322
#define IDSC_INVALID_XML_VER2           3323
#define IDSC_AND                        3324
#define IDSC_OR                         3325
#define IDSC_XMLLOCK_CFG_FAILED         3326
#define IDSC_XMLCREATE_CFG_FAILED       3327
#define IDSC_SAX2FATALERROR             3328
#define IDSC_SAX2ERROR                  3329
#define IDSC_SAX2WARNING                3330
#define IDSC_FILTEREXISTS               3331
#define IDSC_MISSINGXSD                 3345
#define IDSC_CANTVALIDATEXML            3346
#define IDSC_FILTERSKEPT                3347
#define IDSC_EXS_INPUTEMPTY             3350
#define IDSC_EXS_VARNAMEEMPTY           3351
#define IDSC_EXS_FIRSTNOTALPHA          3352
#define IDSC_EXS_VARNAMEINVALID         3353
#define IDSC_EXS_MISSINGCURLYBKT        3354
#define IDSC_EXS_MISSINGSQUAREBKT       3355
#define IDSC_EXS_INVALIDINDEX           3356
#define IDSC_EXS_INDEXNOTNUMERIC        3357
#define IDSC_EXS_UNMATCHEDQUOTES        3358
#define IDSC_EXS_INVALIDBRACKETS        3359
#define IDSC_EXS_MISSINGROUNDBKT        3360
#define IDSC_UNKNOWN                    3361
#define IDSC_XMLEXP_PREFERENCES         3362
#define IDSC_XMLEXP_FILTERACTIVE        3363
#define IDSC_XMLEXP_FLDRESTRICT         3364
#define IDSC_XMLEXP_SUBSETACTIVE        3365
#define IDSC_XMLEXP_SUBSETFIELDS        3366
#define IDSC_UNKNOWNFUNCTION            3367
#define IDSC_UNKNOWNOBJECT              3368
#define IDSC_FSCLEAN                    3369
#define IDSC_FSADDED                    3370
#define IDSC_FSMODIFIED                 3371
#define IDSC_IMPORTENTRY                3372
#define IDSC_IMPORTPSWDNOCOLS           3373
#define IDSC_IMPORTRECNOTFOUND          3374
#define IDSC_IMPORTKNOWNHDRS2           3375
#define IDSC_IMPORT_ON_LINE             3376
#define IDSC_IMPORT_ENTRY_ID            3377
#define IDSC_FILEWRITEERROR             3378
#define IDSC_YES                        3379
#define IDSC_NO                         3380
#define IDSC_NONE                       3381
#define IDSC_USERONHOST                 3382
#define IDSC_UNKNOWNFIELDS              3383
#define IDSC_IMPORTCONFLICTS0           3384
#define IDSC_IMPORTCONFLICTSX1          3385
#define IDSC_IMPORTCONFLICTSX2          3386
#define IDSC_DUPLICATENUMBER            3387
#define IDSC_VALIDATE_DUPLICATES        3388
#define IDSC_IMPORTRECSKIPPED           3389
#define IDSC_VALIDATE_TEXT              3390
#define IDSC_VALIDATE_ENTRY             3391
#define IDSC_VALIDATE_ENTRY2            3392
#define IDSC_ENTRY                      3394
#define IDSC_ENTRIES                    3395
#define IDSC_RELATIVE                   3397
#define IDSC_FILE_UNREADABLE            3398
#define IDSC_FILE_TRUNCATED             3399
#define IDSC_FILE_TOO_SHORT             3400
#define IDSC_FILE_TOO_BIG               3401

#define IDSC_DELETEBASET                3402
#define IDSC_DELETEABASE                3403
#define IDSC_DELETESBASE                3404
#define IDSC_ALIASES                    3405
#define IDSC_SHORTCUTS                  3406
#define IDSC_SEEATTACHMENTFILTERS       3407

#define IDSC_WAS                        3410
#define IDSC_WERE                       3411
#define IDSC_SYNCHUPDATED               3412
#define IDSC_SYNCHCOMPLETED             3413
#define IDSC_MERGECONFLICTS             3414
#define IDSC_MERGECOMPLETED             3415
#define IDSC_CONFLICT                   3416
#define IDSC_CONFLICTS                  3417
#define IDSC_MERGED                     3418
#define IDSC_MERGEADDED                 3419
#define IDSC_CONTAINSANY                3420
#define IDSC_DOESNOTCONTAINANY          3421
#define IDSC_CONTAINSALL                3422
#define IDSC_DOESNOTCONTAINALL          3423
#define IDSC_IMPORTBADFORMAT            3424
#define IDSC_IMPORTABORTED              3425
#define IDSC_IMPORTMISSINGTITLE         3426
#define IDSC_PWHERRORTEXT               3427
#define IDSC_XMLEXP_POLICIES            3428
#define IDSC_MISSINGPOLICYNAME          3429
#define IDSC_MISSINGPOLICYNAMES         3430
#define IDSC_IMPORTPOLICY               3431
#define IDSC_MERGEPOLICY                3432
#define IDSC_ENTRIES_POLICIES           3433
#define IDSC_RENAMEDPOLICYNAMES         3434
#define IDSC_MISSINGPASSWORD            3435
#define IDSC_MISSINGTITLE               3436
#define IDSC_VALIDATE_EMPTYTITLE        3437
#define IDSC_VALIDATE_EMPTYPSWD         3438
#define IDSC_VALIDATE_DUPUUID           3439
#define IDSC_RPTVALIDATE                3440
#define IDSC_VALIDATE_DEPS              3441
#define IDSC_VALIDATE_ERRORS            3442
#define IDSC_VALIDATE_WARNINGS          3443
#define IDSC_SYNCPOLICY                 3444
#define IDSC_COPYPOLICY                 3445
#define IDSC_IMPORTED                   3446
#define IDSC_COPIED                     3447
#define IDSC_KBSHORTCUT_REMOVED         3448
#define IDSC_KBSHORTCUT_USEBYAPP        3449
#define IDSC_REMOVEDKBSHORTCUTS         3450
#define IDSC_XMLCHARACTERERRORS         3451
#define IDSC_EXPORTDESCRIPTION          3452
#define IDSC_VALIDATE_MISSING_ATT       3453
#define IDSC_VALIDATE_ORPHAN_ATT        3454
#define IDSC_VALIDATE_ATTACHMENT        3455
#define IDCS_VALIDATE_NOTSET            3456

// Keep DCA together
#define IDSC_CURRENTDEFAULTDCA          4000
#define IDSC_DCABROWSE                  4001
#define IDSC_DCAAUTOTYPE                4002
#define IDSC_DCACOPYNOTES               4003
#define IDSC_DCACOPYPASSWORD            4004
#define IDSC_DCACOPYUSERNAME            4005
#define IDSC_DCAVIEWEDIT                4006
#define IDSC_DCACOPYPASSWORDMIN         4007
#define IDSC_DCABROWSEPLUS              4008
#define IDSC_DCARUN                     4009
#define IDSC_DCASENDEMAIL               4010
#define IDSC_DEFAULT                    4011

// Named Policy stuff
#define IDSC_PUSELOWER                  4100
#define IDSC_PUSEUPPER                  4101
#define IDSC_PUSEDIGITS                 4102
#define IDSC_PUSESYMBOL                 4103
#define IDSC_YESNUMBER                  4104
#define IDSC_YESEASYVISON               4105
#define IDSC_YESPRONOUNCEABLE           4106
#define IDSC_YESSYMBOLS                 4107
#define IDSC_PLENGTH                    4108
#define IDSC_DEFAULTSYMBOLS             4109
#define IDSC_SPECFICSYMBOLS             4110
#define IDSC_PEASYVISION                4111
#define IDSC_PPRONOUNCEABLE             4112
#define IDSC_PHEXADECIMAL               4113
#define IDSC_DEFAULT_POLICY             4114

==> passwordsafe_0.99+dfsg.orig.tar.gz: pwsafe-0.99BETA/src/core/core.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_FLDNMGROUPTITLE            3003
#define IDSC_FLDNMUSERNAME              3004
#define IDSC_FLDNMPASSWORD              3005
#define IDSC_FLDNMURL                   3006
#define IDSC_FLDNMAUTOTYPE              3007
#define IDSC_FLDNMCTIME                 3008
#define IDSC_FLDNMPMTIME                3009
#define IDSC_FLDNMATIME                 3010
#define IDSC_FLDNMXTIME                 3011
#define IDSC_FLDNMRMTIME                3012
#define IDSC_FLDNMPWHISTORY             3013
#define IDSC_FLDNMNOTES                 3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_UNKNOWN_ERROR              3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_MSXMLPARSEERROR            3043
#define IDSC_MSXMLBADCREATESCHEMA       3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOMSXMLREADER              3047
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_XMLSAVEFAILURE             3051
#define IDSC_SAXERRORPWH                3052
#define IDSC_MSXMLSAXGENERROR           3053
#define IDSC_XERCESSAXGENERROR          3054
#define IDSC_FLDNMGROUP                 3055
#define IDSC_FLDNMTITLE                 3056
#define IDSC_FLDNMPWPOLICY              3057
#define IDSC_FLDNMXTIMEINT              3058
#define IDSC_XERCESPARSEERROR           3059
#define IDCS_XERCESEXCEPTION            3060
#define IDCS_XERCESOUTOFMEMORY          3061
#define IDSC_FLDNMRUNCOMMAND            3063
#define IDSC_FLDNMDCA                   3064
#define IDSC_FLDNMEMAIL                 3065
#define IDSC_FLDNMPROTECTED             3066
#define IDSC_FLDNMUUID                  3067
#define IDSC_FLDNMSYMBOLS               3068
#define IDSC_INVALIDFIELDLENGTH         3069
#define IDSC_INVALIDPWLENGTHX           3070
#define IDSC_FLDNMSHIFTDCA              3071
#define IDSC_FLDNMPWPOLICYNAME          3072
#define IDSC_FLDNMKBSHORTCUT            3073

#define IDSC_CONFIG_NONE                3230
#define IDSC_CONFIG_REGISTRY            3231
#define IDSC_CONFIG_FILE_RO             3232
#define IDSC_CONFIG_FILE_RW             3233

#define IDSC_IMPORTNUMBER               3240
#define IDSC_IMPORTFAILURE              3241
#define IDSC_IMPORTHDR                  3242
#define IDSC_IMPORTMISSINGCOLS          3243
#define IDSC_IMPORTNOCOLS               3244
#define IDSC_READ_ERROR                 3245
#define IDSC_ENCODING_PROBLEM           3246

#define IDSC_FILEREADONLY               3247
#define IDSC_FILEEXISTS                 3248
#define IDSC_INVALIDFLAG                3249
#define IDSC_NOMOREHANDLES              3250
#define IDSC_FILEPATHNOTFOUND           3102
#define IDSC_BADPASSWORD                3251

#define IDSC_REPORTFILENAME             3252
#define IDSC_REPORT_TITLE1              3253
#define IDSC_REPORT_TITLE2              3254
#define IDSC_START_REPORT               3255
#define IDSC_END_REPORT1                3256
#define IDSC_END_REPORT2                3257

#define IDSC_IMPORTNOHEADER             3258
#define IDSC_IMPORTLINESKIPPED          3259
#define IDSC_IMPORTKNOWNHDRS            3260
#define IDSC_IMPORTEMPTYLINESKIPPED     3261
#define IDSC_PWHERRORLINE               3262
#define IDSC_PWHISTORYSKIPPED           3263
#define IDSC_IMPORTCONFLICTS1           3264
#define IDSC_IMPORTCONFLICTS2           3265
#define IDSC_IMPORTINVALIDFIELD         3266
#define IDSC_IMPORTNOPASSWORD           3268
#define IDSC_IMPORTNOTITLE              3269
#define IDSC_VALIDATE_BADUUID           3270
#define IDSC_VALIDATE_PWH               3271
#define IDSC_IMPORTWARNINGHDR           3272
#define IDSC_IMPORTWARNING1             3273
#define IDSC_IMPORTWARNING1A            3274
#define IDSC_IMPORTWARNING2             3275
#define IDSC_IMPORTWARNING2A            3276
#define IDSC_IMPORTWARNING3             3277
#define IDSC_ALIAS                      3278
#define IDSC_SHORTCUT                   3279
#define IDSC_FNORMAL                    3281
#define IDSC_FALIAS                     3282
#define IDSC_FSHORTCUT                  3283
#define IDSC_FALIASBASE                 3284
#define IDSC_FSHORTCUTBASE              3285
#define IDSC_EQUALS                     3286
#define IDSC_DOESNOTEQUAL               3287
#define IDSC_BEGINSWITH                 3288
#define IDSC_DOESNOTBEGINSWITH          3289
#define IDSC_ENDSWITH                   3290
#define IDSC_DOESNOTENDWITH             3291
#define IDSC_CONTAINS                   3292
#define IDSC_DOESNOTCONTAIN             3293
#define IDSC_IS                         3294
#define IDSC_ISNOT                      3295
#define IDSC_ISPRESENT                  3296
#define IDSC_ISNOTPRESENT               3297
#define IDSC_ISACTIVE                   3298
#define IDSC_ISINACTIVE                 3299
#define IDSC_SET                        3300
#define IDSC_NOTSET                     3301
#define IDSC_INVALID                    3302
#define IDSC_BETWEEN                    3303
#define IDSC_LESSTHAN                   3304
#define IDSC_LESSTHANEQUAL              3305
#define IDSC_GREATERTHAN                3306
#define IDSC_GREATERTHANEQUAL           3307
#define IDSC_BEFORE                     3308
#define IDSC_AFTER                      3309
#define IDSC_CASE_INSENSITIVE           3310
#define IDSC_CASE_SENSITIVE             3311
#define IDSC_EXPIRED                    3312
#define IDSC_WILLEXPIRE                 3313
#define IDSC_EXPIRE_IN_DAYS             3314
#define IDSC_SEEPWHISTORYFILTERS        3315
#define IDSC_SEEPWPOLICYFILTERS         3316
#define IDSC_CANTPROCESSDBFILTERS       3317
#define IDSC_INVALID_SCHEMA             3318
#define IDSC_INVALID_SCHEMA_VER         3319
#define IDSC_MISSING_SCHEMA_VER         3320
#define IDSC_MISSING_XML_VER            3321
#define IDSC_INVALID_XML_VER1           3322
#define IDSC_INVALID_XML_VER2           3323
#define IDSC_AND                        3324
#define IDSC_OR                         3325
#define IDSC_XMLLOCK_CFG_FAILED         3326
#define IDSC_XMLCREATE_CFG_FAILED       3327
#define IDSC_SAX2FATALERROR             3328
#define IDSC_SAX2ERROR                  3329
#define IDSC_SAX2WARNING                3330
#define IDSC_FILTEREXISTS               3331
#define IDSC_MISSINGXSD                 3345
#define IDSC_CANTVALIDATEXML            3346
#define IDSC_FILTERSKEPT                3347
#define IDSC_EXPIREPASSWORDS            3348
#define IDSC_NONSAVEDCHANGES            3349
#define IDSC_EXS_INPUTEMPTY             3350
#define IDSC_EXS_VARNAMEEMPTY           3351
#define IDSC_EXS_FIRSTNOTALPHA          3352
#define IDSC_EXS_VARNAMEINVALID         3353
#define IDSC_EXS_MISSINGCURLYBKT        3354
#define IDSC_EXS_MISSINGSQUAREBKT       3355
#define IDSC_EXS_INVALIDINDEX           3356
#define IDSC_EXS_INDEXNOTNUMERIC        3357
#define IDSC_EXS_UNMATCHEDQUOTES        3358
#define IDSC_EXS_INVALIDBRACKETS        3359
#define IDSC_EXS_MISSINGROUNDBKT        3360
#define IDSC_UNKNOWN                    3361
#define IDSC_XMLEXP_PREFERENCES         3362
#define IDSC_XMLEXP_FILTERACTIVE        3363
#define IDSC_XMLEXP_FLDRESTRICT         3364
#define IDSC_XMLEXP_SUBSETACTIVE        3365
#define IDSC_XMLEXP_SUBSETFIELDS        3366
#define IDSC_UNKNOWNFUNCTION            3367
#define IDSC_UNKNOWNOBJECT              3368
#define IDSC_FSCLEAN                    3369
#define IDSC_FSADDED                    3370
#define IDSC_FSMODIFIED                 3371
#define IDSC_IMPORTENTRY                3372
#define IDSC_IMPORTPSWDNOCOLS           3373
#define IDSC_IMPORTRECNOTFOUND          3374
#define IDSC_IMPORTKNOWNHDRS2           3375
#define IDSC_IMPORT_ON_LINE             3376
#define IDSC_IMPORT_ENTRY_ID            3377
#define IDSC_FILEWRITEERROR             3378
#define IDSC_YES                        3379
#define IDSC_NO                         3380
#define IDSC_NONE                       3381
#define IDSC_USERONHOST                 3382
#define IDSC_UNKNOWNFIELDS              3383
#define IDSC_IMPORTCONFLICTS0           3384
#define IDSC_IMPORTCONFLICTSX1          3385
#define IDSC_IMPORTCONFLICTSX2          3386
#define IDSC_DUPLICATENUMBER            3387
#define IDSC_VALIDATE_DUPLICATES        3388
#define IDSC_IMPORTRECSKIPPED           3389
#define IDSC_VALIDATE_TEXT              3390
#define IDSC_VALIDATE_ENTRY             3391
#define IDSC_VALIDATE_ENTRY2            3392
#define IDSC_ENTRY                      3394
#define IDSC_ENTRIES                    3395
#define IDSC_RELATIVE                   3397
#define IDSC_FILE_UNREADABLE            3398
#define IDSC_FILE_TRUNCATED             3399
#define IDSC_FILE_TOO_SHORT             3400
#define IDSC_FILE_TOO_BIG               3401

#define IDSC_DELETEBASET                3402
#define IDSC_DELETEABASE                3403
#define IDSC_DELETESBASE                3404
#define IDSC_ALIASES                    3405
#define IDSC_SHORTCUTS                  3406
#define IDSC_SEEATTACHMENTFILTERS       3407

#define IDSC_WAS                        3410
#define IDSC_WERE                       3411
#define IDSC_SYNCHUPDATED               3412
#define IDSC_SYNCHCOMPLETED             3413
#define IDSC_MERGECONFLICTS             3414
#define IDSC_MERGECOMPLETED             3415
#define IDSC_CONFLICT                   3416
#define IDSC_CONFLICTS                  3417
#define IDSC_MERGED                     3418
#define IDSC_MERGEADDED                 3419
#define IDSC_CONTAINSANY                3420
#define IDSC_DOESNOTCONTAINANY          3421
#define IDSC_CONTAINSALL                3422
#define IDSC_DOESNOTCONTAINALL          3423
#define IDSC_IMPORTBADFORMAT            3424
#define IDSC_IMPORTABORTED              3425
#define IDSC_IMPORTMISSINGTITLE         3426
#define IDSC_PWHERRORTEXT               3427
#define IDSC_XMLEXP_POLICIES            3428
#define IDSC_MISSINGPOLICYNAME          3429
#define IDSC_MISSINGPOLICYNAMES         3430
#define IDSC_IMPORTPOLICY               3431
#define IDSC_MERGEPOLICY                3432
#define IDSC_ENTRIES_POLICIES           3433
#define IDSC_RENAMEDPOLICYNAMES         3434
#define IDSC_MISSINGPASSWORD            3435
#define IDSC_MISSINGTITLE               3436
#define IDSC_VALIDATE_EMPTYTITLE        3437
#define IDSC_VALIDATE_EMPTYPSWD         3438
#define IDSC_VALIDATE_DUPUUID           3439
#define IDSC_RPTVALIDATE                3440
#define IDSC_VALIDATE_DEPS              3441
#define IDSC_VALIDATE_ERRORS            3442
#define IDSC_VALIDATE_WARNINGS          3443
#define IDSC_SYNCPOLICY                 3444
#define IDSC_COPYPOLICY                 3445
#define IDSC_IMPORTED                   3446
#define IDSC_COPIED                     3447
#define IDSC_KBSHORTCUT_REMOVED         3448
#define IDSC_KBSHORTCUT_USEBYAPP        3449
#define IDSC_REMOVEDKBSHORTCUTS         3450
#define IDSC_XMLCHARACTERERRORS         3451
#define IDSC_EXPORTDESCRIPTION          3452
#define IDSC_VALIDATE_MISSING_ATT       3453
#define IDSC_VALIDATE_ORPHAN_ATT        3454
#define IDSC_VALIDATE_ATTACHMENT        3455
#define IDCS_VALIDATE_NOTSET            3456

// Keep DCA together
#define IDSC_CURRENTDEFAULTDCA          4000
#define IDSC_DCABROWSE                  4001
#define IDSC_DCAAUTOTYPE                4002
#define IDSC_DCACOPYNOTES               4003
#define IDSC_DCACOPYPASSWORD            4004
#define IDSC_DCACOPYUSERNAME            4005
#define IDSC_DCAVIEWEDIT                4006
#define IDSC_DCACOPYPASSWORDMIN         4007
#define IDSC_DCABROWSEPLUS              4008
#define IDSC_DCARUN                     4009
#define IDSC_DCASENDEMAIL               4010
#define IDSC_DEFAULT                    4011

#define IDSC_STATCOMPANY                4020
#define IDSC_STATAUTOTYPE               4021
#define IDSC_STATBROWSE                 4022
#define IDSC_STATCOPYNOTES              4023
#define IDSC_STATCOPYPASSWORD           4024
#define IDSC_STATCOPYUSERNAME           4025
#define IDSC_STATVIEWEDIT               4026
#define IDSC_STATCOPYPASSWORDMIN        4027
#define IDSC_STATBROWSEPLUS             4030
#define IDSC_STATRUN                    4031
#define IDSC_STATSENDEMAIL              4032


// Named Policy stuff
#define IDSC_PUSELOWER                  4100
#define IDSC_PUSEUPPER                  4101
#define IDSC_PUSEDIGITS                 4102
#define IDSC_PUSESYMBOL                 4103
#define IDSC_YESNUMBER                  4104
#define IDSC_YESEASYVISON               4105
#define IDSC_YESPRONOUNCEABLE           4106
#define IDSC_YESSYMBOLS                 4107
#define IDSC_PLENGTH                    4108
#define IDSC_DEFAULTSYMBOLS             4109
#define IDSC_SPECFICSYMBOLS             4110
#define IDSC_PEASYVISION                4111
#define IDSC_PPRONOUNCEABLE             4112
#define IDSC_PHEXADECIMAL               4113
#define IDSC_DEFAULT_POLICY             4114
